package
Version:
v0.0.0-...-645e8bd
Opens a new window with list of versions in this module.
Published: Jan 17, 2020
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
func GetWeather(key, city, measurement string) (d data)
Get Weather Data and place it into a Struct
Source Files
¶
Click to show internal directories.
Click to hide internal directories.